
rm(list=ls())

setwd("/Users/kahrens/MyProjects/policy_tree")

library("tidyverse")
library("readr")
library("policytree")
library("grf")
library("glmnet")
library("glmnetUtils")
library(DiagrammeR)
library("foreach")
library("parallel")
library("readxl")
library("xtable")

source("./Code/auxiliary_functions.R")

data_folder <- "/Volumes/pp/projects/zh-citizenship-21/Policy_tree/Data_raw"
out_folder <- "/Users/kahrens/MyProjects/policy_tree/Outputs"
data_processed_folder <- "/Volumes/pp/projects/zh-citizenship-21/Policy_tree/Data"
paper_out_path <- "/Users/kahrens/MyProjects/policy_tree/Outputs"
models_folder <- "/Users/kahrens/MyProjects/policy_tree/Models/"


load(file=paste0(data_processed_folder,"/data_matrices.RData"))

train_size <- nrow(X1)
test_size <- nrow(X2)

###############################################################
### cross-validation                                        ###
###############################################################

set.seed(1308)

iter <- 500

cl <- parallel::makeCluster(12)
doParallel::registerDoParallel(cl)

y_list <- foreach(i = 1:iter,.packages=c("policytree","grf","tidyverse")) %dopar% {
  
  # split randomly in test and train
  train_or_test <- sample(x=c(TRUE,FALSE),prob=c(train_size/(train_size+test_size),
                                                 test_size/(train_size+test_size)
                                                ),
                      size=nrow(X1) , replace=TRUE) 
  
  # sample with replacement
  btrain <- sample(which(train_or_test==1),replace=TRUE,size=train_size)
  btest <- sample(which(train_or_test==0),replace=TRUE,size=test_size)
  
  X1_b <- X1[btrain,]
  X2_b <- X1[btest,]
  Y1_b <- Y1[btrain]
  Y2_b <- Y1[btest]
  W1_b <- W1[btrain]
  W2_b <- W1[btest]
  n2_b <- nrow(X2_b)
  
  ## policy learning using first wave data
  multi.forest <- grf::multi_arm_causal_forest(X1_b,Y1_b,W1_b,W.hat =c(2/5,1/5,1/5,1/5))
  # Compute doubly robust reward estimates.
  Gamma.matrix <- double_robust_scores(multi.forest)
  
  # fit policy trees
  pol_fit2 <- policy_tree(X1_b,Gamma.matrix,2)
  W2_tree2 <- predict(pol_fit2,newdata=X2_b)-1
  W2_tree2 <- factor(W2_tree2,levels=0:3)
  
  pol_fit3 <- policy_tree(X1_b,Gamma.matrix,3)
  W2_tree3 <- predict(pol_fit3,newdata=X2_b)-1
  W2_tree3 <- factor(W2_tree3,levels=0:3)

  pol_fit4 <- hybrid_policy_tree(X1_b,Gamma.matrix,4)
  W2_tree4 <- predict(pol_fit4,newdata=X2_b)-1
  W2_tree4 <- factor(W2_tree4,levels=0:3)  
    
  # obtain oos reward, i.e. mu^(a)
  oos <- get_oos_reward(fit=multi.forest,x1=X1_b,y1=Y1_b,x2=X2_b)
  mu2.hat <- oos$mu.hat
  
  # different scenarios
  W2_random <- myrandom(n2_b)
  W2_max <- as.factor(apply(mu2.hat,1,which.max)-1)
  
  Y2_tree2 <- policy_multiply4(mu2.hat,W2_tree2) 
  Y2_tree3 <- policy_multiply4(mu2.hat,W2_tree3)
  Y2_tree4 <- policy_multiply4(mu2.hat,W2_tree4)
  Y2_random <- policy_multiply4(mu2.hat,W2_random)
  Y2_alw0 <- policy_multiply4(mu2.hat,rep("0",n2_b))  
  Y2_alw1 <- policy_multiply4(mu2.hat,rep("1",n2_b))  
  Y2_alw2 <- policy_multiply4(mu2.hat,rep("2",n2_b))  
  Y2_alw3 <- policy_multiply4(mu2.hat,rep("3",n2_b))  
  Y2_max <-policy_multiply4(mu2.hat,W2_max)  

  ## testing and output
  out <- cbind(Y2_alw0,Y2_alw1,Y2_alw2,Y2_alw3,Y2_random,Y2_tree2,Y2_tree3,Y2_tree4,Y2_max)
  diff_table <- matrix(rep(NA,ncol(out)^2),ncol=ncol(out))
  se_table <-  matrix(rep(NA,ncol(out)^2),ncol=ncol(out))
  stat_table <-  matrix(rep(NA,ncol(out)^2),ncol=ncol(out))
  p_table <-  matrix(rep(NA,ncol(out)^2),ncol=ncol(out))
  for (i in 1:ncol(out)) {
    for (j in 1:ncol(out)) {
      if (j<i) {
        fit <- t.test(out[,i],out[,j])
        diff_table[j,i]<-fit$estimate[1]-fit$estimate[2]
        se_table[j,i]<-fit$stderr
        stat_table[j,i]<-fit$statistic
        p_table[j,i]<-fit$p.value
      }
    }
  }
  list(se_table=se_table,
       stat_table=stat_table,
       diff_table=diff_table,
       p_table=p_table,
       outmean=colMeans(out))
  
}
parallel::stopCluster(cl)

save(y_list,file=paste(models_folder,"ylist.RData"))
#load(file="ylist.RData")

# collapse matrices
iter <- length(y_list)
(diff_mat <- Reduce("+",lapply(y_list,function(x) x$diff_table))/iter)
(se_mat <- sqrt(Reduce("+",lapply(y_list,function(x) (x$diff_table-diff_mat)^2))/iter))
(Reduce("+",lapply(y_list,function(x) abs(x$stat_table)>1.96))/iter)
(Reduce("+",lapply(y_list,function(x) x$p_table<0.05))/iter)
boot_stat <- diff_mat/se_mat
boot_stat

### formatting
( coefmat <- format(round(100*diff_mat,3),nsmall=3,na.encode=F) )
(se_mat <-   format(round(se_mat*100,3),nsmall=3))
for (i in 1:ncol(coefmat)) {
  for (j in 1:ncol(coefmat)) {
      coefmat[i,j] <- str_replace(coefmat[i,j],"NA","")
      se_mat[i,j] <- str_replace(se_mat[i,j],"NA","")
      if (j>i) se_mat[i,j] <- paste0("(",se_mat[i,j],")")
      stars <- case_when(boot_stat[i,j]>qnorm(0.995)~"\\starsss",
                         boot_stat[i,j]>qnorm(0.975)~"\\starss",
                         boot_stat[i,j]>qnorm(0.95)~"\\stars",
                         TRUE~"")
      coefmat[i,j] <- paste0(coefmat[i,j],stars)
  }
}

colnames(coefmat)  <- rownames(coefmat) <- 
  c("Nothing","Always 1","Always 2",
    "Always 3","Random",
    "Policy tree ($d=2$)","Policy tree ($d=3$)","Hybrid tree ($d=2$)","Maximum rule")
(se_mat)
(coefmat)

se_mat <- se_mat[,2:9]
coefmat <- coefmat[,2:9]
se_mat <- se_mat[1:8,]
coefmat <- coefmat[1:8,]
(se_mat)
(coefmat)


out_table <-  rbind(coefmat,se_mat)
out_table <-  out_table[c(1,9,2,10,3,11,4,12,5,13,6,14,7,15,8,16  ),]
 (out_table)

out_table <- as_tibble(out_table,rownames="names")
(out_table)

out_table %>%
  xtable() %>%
  print.xtable(sanitize.text.function = function(x){x},
               include.colnames = T,
               include.rownames = FALSE,
               only.contents = TRUE,
               file=paste0(paper_out_path,"/tables/comparison_table.tex")
  )
 