clear all

adopath + "/Users/kahrens/MyProjects/ddml"
adopath + "/Users/kahrens/MyProjects/pystacked"


import delimited ///
	"/Volumes/pp/projects/zh-citizenship-21/Policy_tree/Data/Final_for_analysis.csv", ///
	delim(",")

cd "/Users/kahrens/MyProjects/policy_tree"

cap log close
log using "Code/logs/6_final_analysis.log", text replace

which pystacked
which ddml
which pdslasso

global outpath /Users/kahrens/MyProjects/policy_tree/Outputs/tables

 foreach var of varlist policy_rule policy_rule2 region4 {
	gen `var'_str = `var'
	replace `var'="" if `var'=="NA"
	encode `var', gen(`var'_en)
	drop `var'
	rename `var'_en `var'
}

global rflow max_depth(10) max_features(sqrt) n_estimators(500)
global rfmid max_depth(6) max_features(sqrt) n_estimators(500)
global rfhigh max_depth(2) max_features(sqrt) n_estimators(500)
global grad1 max_depth(6) n_estimators(1000) learning_rate(0.01) validation_fraction(0.2) n_iter_no_change(5) tol(0.01)
global grad2 max_depth(3) n_estimators(1000) learning_rate(0.01) validation_fraction(0.2) n_iter_no_change(5) tol(0.01)
global grad3 max_depth(6) n_estimators(1000) learning_rate(0.1) validation_fraction(0.2) n_iter_no_change(5) tol(0.01)
global grad4 max_depth(3) n_estimators(1000) learning_rate(0.1) validation_fraction(0.2) n_iter_no_change(5) tol(0.01)
global nnetopt hidden_layer_sizes(20 20)

gen p2_complexity=0 if !missing(policy_rule2)
gen p2_tree=0 if !missing(policy_rule2)
gen p2_requirements=0 if !missing(policy_rule2)
gen p2_welcome=0 if !missing(policy_rule2)
gen p2_none=0 if !missing(policy_rule2)
replace p2_complexity=1 if policy_rule2_str=="Always Complexity"
replace p2_tree=1 if policy_rule2_str=="Policy tree"
replace p2_requirements=1 if policy_rule2_str=="Always Requirements"
replace p2_welcome=1 if policy_rule2_str=="Always Welcome"
replace p2_none=1 if policy_rule2_str=="Nothing"

gen p1_random=0 if !missing(policy_rule)
gen p1_tree=0 if !missing(policy_rule)
gen p1_none=0 if !missing(policy_rule)
replace p1_random=1 if policy_rule_str=="Random"
replace p1_tree=1 if policy_rule_str=="Policy tree"
replace p1_none=1 if policy_rule_str=="Nothing"

global controls female ibn.region4 age time_in_zh time_in_ch ibn.wave_period
global controls2 c.($controls)##c.($controls)

global pyset type(reg) m(ols lassocv ridgecv rf rf rf gradboost gradboost gradboost gradboost) cmdopt4($rflow) cmdopt5($rfmid) cmdopt6($rfhigh) cmdopt7($grad1) cmdopt8($grad2) cmdopt9($grad3) cmdopt10($grad4) njobs(6) 
global pyset m(ols)



************************************
*** estimation
************************************

set seed 12345

*** ddml

if (1) {
	ddml init partial, kfolds(10) reps(5)
	ddml E[Y|X]: pystacked applied $controls2, $pyset 
	ddml E[D|X]: pystacked p1_tree $controls2, $pyset
	ddml E[D|X]: pystacked p1_random $controls2, $pyset
	ddml crossfit
	ddml estimate , robust  nocons  vce(cluster idx)

	estimates store ddml1
	estimates save Models/ddml1, replace

	*ddml drop
} 
else {
	estimates use Models/ddml1
	estimates store ddml1	
}
	lincom p1_tree-p1_random
	estadd scalar tree_vs_random = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_random_se= "(`se')"
	sum applied  
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "DDML"
	
if (1) {
	ddml init partial, kfolds(10) reps(5)
	ddml E[Y|X]: pystacked applied $controls2, $pyset 
	ddml E[D|X]: pystacked p2_tree $controls2, $pyset
	ddml E[D|X]: pystacked p2_comple $controls2, $pyset
	ddml E[D|X]: pystacked p2_req $controls2, $pyset
	ddml E[D|X]: pystacked p2_wel $controls2, $pyset
	ddml crossfit
	ddml estimate , robust  nocons  vce(cluster idx)

	estimates store ddml2
	estimates save Models/ddml2, replace

	*ddml drop
}
else {
	estimates use Models/ddml2
	estimates store ddml2
}

	lincom p2_tree-p2_com
	estadd scalar tree_vs_com = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_com_se= "(`se')"
	lincom p2_tree-p2_req
	estadd scalar tree_vs_req = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_req_se= "(`se')"
	lincom p2_tree-p2_wel
	estadd scalar tree_vs_wel = r(estimate)	
	local se = round(r(se),0.001)
	estadd local tree_vs_wel_se= "(`se')"
	sum applied  
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "DDML"
	
	
*** wave 1-2 OLS
reg applied p1_tree p1_random $controls , vce(cluster idx)
estimates store ols1
	lincom p1_tree-p1_random
	estadd scalar tree_vs_random = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_random_se= "(`se')"
	sum applied if e(sample)
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "OLS"
	
	
reg applied  p2_tree p2_com p2_req p2_wel $controls , vce(cluster idx)
estimates store ols2
	lincom p2_tree-p2_com
	estadd scalar tree_vs_com = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_com_se= "(`se')"
	lincom p2_tree-p2_req
	estadd scalar tree_vs_req = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_req_se= "(`se')"
	lincom p2_tree-p2_wel
	estadd scalar tree_vs_wel = r(estimate)	
	local se = round(r(se),0.001)
	estadd local tree_vs_wel_se= "(`se')"
	sum applied if e(sample)
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "OLS"
	

*** wave 1-2 pds lasso
pdslasso applied p1_tree p1_random   ($controls2), cluster( idx)
estimates store pds1
	lincom p1_tree-p1_random
	estadd scalar tree_vs_random = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_random_se= "(`se')"
	sum applied if e(sample)
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "PDS lasso"
	
	
pdslasso applied p2_tree p2_com p2_req p2_wel ($controls2), cluster( idx) 
estimates store pds2
	lincom p2_tree-p2_com
	estadd scalar tree_vs_com = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_com_se= "(`se')"
	lincom p2_tree-p2_req
	estadd scalar tree_vs_req = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_req_se= "(`se')"
	lincom p2_tree-p2_wel
	estadd scalar tree_vs_wel = r(estimate)	
	local se = round(r(se),0.001)
	estadd local tree_vs_wel_se= "(`se')"	
	sum applied if e(sample)
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "PDS lasso"

	
*** wave 2 OLS
reg applied p1_tree $controls  if wave_period==2, vce(cluster idx)
estimates store ols_w2_1
	lincom p1_tree 
	estadd scalar tree_vs_random = r(estimate)
	local se = round(r(se),0.001)
	estadd local tree_vs_random_se= "(`se')"
	sum applied if e(sample)
	local avg = round(r(mean),0.01)
	estadd local ymean = "`avg'"
	estadd local est = "OLS"


	
	
************************************
*** export
************************************


esttab  ols_w2_1 ols1 ols2 pds1 pds2 ddml1 ddml2 ///
		, replace ///
		keep(p1* p2*) ///
		nobaselevels ///	
		rename(p2_tree p1_tree) ///
		coeflabels(p1_tree "Policy tree" ///
					p2_tree "Policy tree" ///
					p1_tree "Policy tree" ///
					p2_welcome "Welcome" ///
					p2_complexity "Complexity" ///
					p2_requirements "Requirements" ///
					p1_random "Random" ///
					) se ///
		scalars("tree_vs_random ~~Random" ///
				"tree_vs_random_se ~" ///
				"tree_vs_com ~~Complexity" ///
				"tree_vs_com_se ~" ///
				"tree_vs_req ~~Requirements" /// 
				"tree_vs_req_se ~" ///
				"tree_vs_wel ~~Welcome" /// 
				"tree_vs_wel_se ~" ///
				"est Estimator" ///
				"ymean Outcome~mean" ///
				"N Observations") noobs 

				
esttab  ols_w2_1 ols1 ols2 pds1 pds2 ddml1 ddml2 ///
		using "$outpath/main_output.tex" ///
		, replace ///
		keep(p1* p2*) ///
		nobaselevels ///	
		rename(p2_tree p1_tree) ///
		coeflabels(p1_tree "Policy tree" ///
					p2_tree "Policy tree" ///
					p1_tree "Policy tree" ///
					p2_welcome "Welcome" ///
					p2_complexity "Complexity" ///
					p2_requirements "Requirements" ///
					p1_random "Random" ///
					) se ///
		scalars("tree_vs_random ~~Random" ///
				"tree_vs_random_se ~" ///
				"tree_vs_com ~~Complexity" ///
				"tree_vs_com_se ~" ///
				"tree_vs_req ~~Requirements" /// 
				"tree_vs_req_se ~" ///
				"tree_vs_wel ~~Welcome" /// 
				"tree_vs_wel_se ~" ///
				"est Estimator" ///
				"ymean Outcome~mean" ///
				"N Observations") noobs 
				
log close
