ipw.multi_arm_causal_forest <- function(object, outcome = 1, ...) {
  outcome <- outcome[1]
  if (!outcome %in% 1:NCOL(object$Y.orig)) {
    outcome <- match(outcome, colnames(object$Y.orig, do.NULL = FALSE))
    if (is.na(outcome)) {
      stop("`outcome` should be a column number/name specifying a column in Y.")
    }
  } else {
    outcome <- as.integer(outcome)
  }
  treatment.names <- levels(object$W.orig)
  num.treatments <- length(treatment.names)
  num.samples <- nrow(object$W.hat)
  observed.treatment <- match(object$W.orig, treatment.names)
  observed.treatment.idx <- cbind(seq_along(object$W.orig), observed.treatment)
  
  mu.matrix <- conditional_means(object, outcome)
  YY <- matrix(0, num.samples, num.treatments)
  IPW <- matrix(0, num.samples, num.treatments)
  YY[observed.treatment.idx] <- object$Y.orig[, outcome]
  IPW[observed.treatment.idx] <- 1 / object$W.hat[observed.treatment.idx]
  Gamma.matrix <- (YY  ) * IPW  
  
  Gamma.matrix
}